**Example 1: 实例token授权**



Input: 

```
tccli ckafka CancelAuthorizationToken --cli-unfold-argument  \
    --User testUser \
    --InstanceId ckafka-xxxasa \
    --Tokens asdadsda
```

Output: 
```
{
    "Response": {
        "Result": 0,
        "RequestId": "20e995ed-75b9-43bb-84c0-35676567e1a8"
    }
}
```

